Pipeline
========

.. automodule:: metacells.pipeline

.. automodule:: metacells.pipeline.related_genes
    :members:

.. automodule:: metacells.pipeline.exclude
    :members:

.. automodule:: metacells.pipeline.mark
    :members:

.. automodule:: metacells.pipeline.select
    :members:

.. automodule:: metacells.pipeline.direct
    :members:

.. automodule:: metacells.pipeline.divide_and_conquer
    :members:

.. automodule:: metacells.pipeline.collect
    :members:

.. automodule:: metacells.pipeline.umap
    :members:

.. automodule:: metacells.pipeline.projection
    :members:

.. automodule:: metacells.pipeline.mcview
    :members:

